Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Merge ¶
Merge returns a map merge function that merges its src map into its dest map at the specified path, mutating the destination map. For instance, Merge allows merging in CLI flag configuration settings at any level deeper inside your root configuration map.
The returned merge function has the following properties:
- non-strict
- creates or replaces the values along the src merge root path with key-value maps as necessary.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.